package Mojo::Transaction::Single;

use strict;
use warnings;

# DEPRECATED in Snowman!
# Use Mojo::Transaction::HTTP instead.
use base 'Mojo::Transaction::HTTP';

1;
__END__

=head1 NAME

Mojo::Transaction::Single - DEPRECATED!

=head1 SYNOPSIS

    # This module is deprecated, use Mojo::Transaction::HTTP instead

=head1 DESCRIPTION

L<Mojo::Transaction::Single> is deprecated, use L<Mojo::Transaction::HTTP>
instead.

=head1 ATTRIBUTES

L<Mojo::Transaction::Single> inherits all attributes from
L<Mojo::Transaction::HTTP>.

=head1 METHODS

L<Mojo::Transaction::Single> inherits all methods from
L<Mojo::Transaction::HTTP>.

=head1 SEE ALSO

L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicious.org>.

=cut
